@@ -9,18 +9,13 @@ from django.db.models import ForeignKey
 class AdminVisualSortableInlineMixin:
     is_adminvisualsortable = True
 
-class AdminVisualSortableMixin:
-    @property
-    def change_list_template(self):
-        opts = self.model._meta
-        app_label = opts.app_label
-        return str(Path('change_list.html'))
-
 class AdminVisualSortableBaseMixin:
+    ''' Admin Model mandatory if Inlines has Sortable Elements '''
     is_adminvisualsortable = True
     change_form_template =  str(Path('change_form.html'))
 
     def has_sort_elements(self, object_id):
+        ''' Check if Parent Model has Sortable Inlines '''
         TargetModel = self.model.__name__
         inline_list = get_model_inlines(TargetModel)
         for ModelInline in inline_list:
@@ -39,4 +34,16 @@ class AdminVisualSortableBaseMixin:
         extra_context['has_sort_elements'] = self.has_sort_elements(object_id)
         return super().change_view(
             request, object_id, form_url, extra_context=extra_context,
-        )
\ No newline at end of file
+        )
+
+class AdminVisualSortableMixin(AdminVisualSortableBaseMixin):
+    ''' Admin Model for the Sortable Parent Model'''
+    @property
+    def change_list_template(self):
+        opts = self.model._meta
+        app_label = opts.app_label
+        return str(Path('change_list.html'))
+
+class AdminVisualSortableTabbedMixin(AdminVisualSortableMixin):
+    ''' Admin Model With Correct Template if Tabbed Admin is in Use '''
+    change_form_template =  str(Path('tabbed_change_form.html'))
