@@ -16,20 +16,19 @@ def get_child_sortable_list(value):
         return None
     except IndexError:
         return None
-
     return reverse('adminvisualsortable:sortable inlines', kwargs={'app': app_name, 'modelparentname': model_name, 'model_id': obj_id })
 
 
 @register.filter(name='get_parent_visualorder_url')
 def get_parent_visualorder_url(value):
     obj = value
-    return '{}/adminvisualsortable/{}/{}/'.format(settings.HOST, obj._meta.app_label, obj.__class__.__name__.lower())
+    return '/adminvisualsortable/{}/{}/'.format(obj._meta.app_label, obj.__class__.__name__.lower())
 
 
 @register.filter(name='get_parent_admin_url_detail')
 def get_parent_admin_url_detail(value):
     obj = value
-    return '{}/admin/{}/{}/{}'.format(settings.HOST, obj._meta.app_label, obj.__class__.__name__.lower(), obj.id)
+    return '/admin/{}/{}/{}'.format(obj._meta.app_label, obj.__class__.__name__.lower(), obj.id)
 
 
 @register.filter(name='get_parent_admin_url_list')
@@ -37,4 +36,4 @@ def get_parent_admin_url_list(value):
     model = value
     modelname = model['name'].lower()
     app = model['app_name']
-    return '{}/admin/{}/{}/'.format(settings.HOST, app, modelname)
\ No newline at end of file
+    return '/admin/{}/{}/'.format(app, modelname)
